Architecture — fabulist 1.2.0 documentation

# Architecture

## Class Inheritance Diagram

digraph inheritancef809efae7f { rankdir=LR; size="8.0, 12.0"; "AdjList" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Implement a collection of adjectives."]; "_WordList" -> "AdjList" [arrowsize=0.5,style="setlinewidth(0.5)"]; "AdvList" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Implement a collection of adverbs."]; "_WordList" -> "AdvList" [arrowsize=0.5,style="setlinewidth(0.5)"]; "ApplyTemplateError" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Raised when a template could not be resolved."]; "Fabulist" [URL="fabulist_module.html#fabulist.fabulist.Fabulist",fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",target="_top",tooltip="Random string factory."]; "FirstnameList" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="List of first names, tagged by gender."]; "_WordList" -> "FirstnameList" [arrowsize=0.5,style="setlinewidth(0.5)"]; "LastnameList" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="List of last names."]; "_WordList" -> "LastnameList" [arrowsize=0.5,style="setlinewidth(0.5)"]; "Macro" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Parses and represents a macro with type, modifiers, tags, and references."]; "NameList" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Implement a virtual collection of person names."]; "_WordList" -> "NameList" [arrowsize=0.5,style="setlinewidth(0.5)"]; "NounList" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Implement a collection of nouns."]; "_WordList" -> "NounList" [arrowsize=0.5,style="setlinewidth(0.5)"]; "VerbList" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Implement a collection of verbs."]; "_WordList" -> "VerbList" [arrowsize=0.5,style="setlinewidth(0.5)"]; "_WordList" [URL="fabulist_module.html#fabulist.fabulist._WordList",fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",target="_top",tooltip="Common base class for all word lists."]; } digraph inheritancec600c5cd76 { rankdir=LR; size="8.0, 12.0"; "LoremDialect" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Generate lorem ipsum text."]; "LoremGenerator" [URL="lorem_ipsum_module.html#fabulist.lorem_ipsum.LoremGenerator",fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",target="_top",tooltip="Generate lorem ipsum text in a given dialect."]; }